<?php declare(strict_types=1);

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\Mapping as ORM;

/**
 * Class Topic
 * @ORM\Entity(repositoryClass="App\Repository\TopicRepository")
 * @ORM\Table(name="topic")
 * @package App\Entity
 */
class Topic
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     */
    protected int $id;

    /** @ORM\Column(columnDefinition="VARCHAR(20)", length=20) */
    protected string $label;

    /** @ORM\OneToMany(
     *     cascade={"persist", "remove"},
     *     fetch="EAGER",
     *     mappedBy="topic",
     *     orphanRemoval=true,
     *     targetEntity="App\Entity\Question"
     * )
     */
    protected ArrayCollection $questions;

    public function __construct()
    {
        $this->questions = new ArrayCollection();
    }

    public function getId() : ?int
    {
        return $this->id;
    }

    public function getLabel() : ?string
    {
        return $this->label;
    }

    public function setLabel(string $label) : self
    {
        $this->label = $label;
        return $this;
    }

    public function addQuestion(Question $question) : self
    {
        $this->questions->add($question);
        return $this;
    }

    public function removeQuestion(Question $question): self
    {
        $this->questions->removeElement($question);
        return $this;
    }
}